#
# spec file for package spice-vdagent
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2014 B1 Systems GmbH, Vohburg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#This test doesn't work right in build service, but does outside of it
%bcond_with session_info_test

Name:           spice-vdagent
Version:        0.22.1
Release:        4.5
Summary:        Agent for Spice guests
License:        GPL-3.0-or-later
Group:          System/Daemons
URL:            http://spice-space.org/
Source:         http://spice-space.org/download/releases/%{name}-%{version}.tar.bz2
Source2:        %{name}.keyring
Patch0:         harden_spice-vdagentd.service.patch
# https://gitlab.freedesktop.org/spice/linux/vd_agent/-/merge_requests/47
Patch1:         0001-Switch-to-spice-vdagent.service-by-default.patch
BuildRequires:  alsa-devel  >= 1.0.22
BuildRequires:  desktop-file-utils
BuildRequires:  libXfixes-devel
BuildRequires:  libXinerama-devel
BuildRequires:  libXrandr-devel >= 1.3
BuildRequires:  libpciaccess-devel >= 0.10
BuildRequires:  libtool
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(gio-2.0) >= 2.50
BuildRequires:  pkgconfig(glib-2.0) >= 2.58
BuildRequires:  pkgconfig(gobject-2.0) >= 2.50
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(spice-protocol) >= 0.14.3
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(udev)
Supplements:    modalias(xorg-x11-server:virtio:d00000003v*)
%{?systemd_requires}

%description
Spice agent for Linux guests offering the following features:

Features:
* Client mouse mode (no need to grab mouse by client, no mouse lag)
  this is handled by the daemon by feeding mouse events into the kernel
  via uinput. This will only work if the active X-session is running a
  spice-vdagent process so that its resolution can be determined.
* Automatic adjustment of the X-session resolution to the client resolution
* Support of copy and paste (text and images) between the active X-session
  and the client

%prep
%autosetup -p1

%build
autoreconf
%configure \
  --with-session-info=systemd \
  --with-init-script=systemd
make %{?_smp_mflags} V=2

%check
%if %{with session_info_test}
make check V=2
%endif

%install
make install DESTDIR=%{buildroot} V=2
# create rc symlink
ln -s  service %{buildroot}%{_sbindir}/rcspice-vdagentd

mkdir -p %{buildroot}%{_datadir}/gdm/greeter/autostart

mv %{buildroot}%{_datadir}/gdm/autostart/LoginWindow/*.desktop %{buildroot}%{_datadir}/gdm/greeter/autostart
rm -fr %{buildroot}%{_datadir}/gdm/autostart

%pre
%service_add_pre spice-vdagentd.service
%service_add_pre spice-vdagentd.socket

%post
%service_add_post spice-vdagentd.service
%service_add_post spice-vdagentd.socket
%tmpfiles_create %_tmpfilesdir/spice-vdagentd.conf

%preun
%service_del_preun spice-vdagentd.service
%service_del_preun spice-vdagentd.socket

%postun
%service_del_postun spice-vdagentd.service
%service_del_postun spice-vdagentd.socket

%files
%defattr(-,root,root)
%doc CHANGELOG.md README.md
%license COPYING
%ghost /run/spice-vdagentd
%{_udevrulesdir}/70-spice-vdagentd.rules
%{_unitdir}/spice-vdagentd.service
%{_unitdir}/spice-vdagentd.socket
%{_prefix}/lib/systemd/user/spice-vdagent.service
%{_tmpfilesdir}/spice-vdagentd.conf
%{_bindir}/spice-vdagent
%{_sbindir}/spice-vdagentd
%{_sbindir}/rcspice-vdagentd
%{_sysconfdir}/xdg/autostart/spice-vdagent.desktop
# For /usr/share/gdm/autostart/LoginWindow/spice-vdagent.desktop
# We own the dir too, otherwise we must Require gdm
%{_datadir}/gdm
%{_mandir}/man1/%{name}*.1*

%changelog
* Thu Feb  9 2023 Fabian Vogt <fvogt@suse.com>
- Drop allow-enable-on-boot-spice-vdagentd.service.patch. udev takes
  care of this already.
- Don't call systemctl enable in %%post, that's what presets are for.
- Add 0001-Switch-to-spice-vdagent.service-by-default.patch to allow
  use of spice-vdagent.service
* Mon Oct 10 2022 carnold@suse.com
- bsc#1204085 - spice-vdagentd 0.22.1 doesn't work properly on
  guest
  allow-enable-on-boot-spice-vdagentd.service.patch
* Tue Oct  4 2022 carnold@suse.com
- jsc#PED-2113 [Virt Tools] Refresh Virtualization Tools for Xen
  and KVM Management
* Fri Feb 11 2022 carnold@suse.com
- Update to version 0.22.1. Features and Issues addressed:
  * !40 - Handle side mouse buttons
  * !39 - Set retry limit to connect to vdagentd and improve logging error
  * !35 - Fix deprecation warning
  * !37 - Provide systemd spice-vdagent.service
  Do not process X11 events in vdagent_x11_create
  Drop upstream signature file as having "No public key"
* Thu Dec 16 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_spice-vdagentd.service.patch
* Fri Jan 15 2021 Bruce Rogers <brogers@suse.com>
- Update to version 0.21.0
  * Changes include:
  * Security fixes:
  CVE-2020-25650, CVE-2020-25651, CVE-2020-25652, CVE-2020-25653
  * Fix shutdown issue due to incompatible thread/fork uses with GLib
  * Fix mouse pointer issues under Wayland
  * Fix a crash when running without dbus (e.g: within containers)
  * !9  - Introduce optional GTK4 support for monitor management
  * !13 - Enable copying files from client using webdav
  * Bump spice-protocol dependency to v0.14.3
  * Drop all patches, since they are in base tarball now:
  Add-a-test-for-session_info.patch
  Avoids-unchecked-file-transfer-IDs-allocation-and-us.patch
  Avoids-uncontrolled-active_xfers-allocations.patch
  Avoids-unlimited-agent-connections.patch
  Avoids-user-session-hijacking.patch
  Better-check-for-sessions.patch
  cleanup-active_xfers-when-the-client-disconnects.patch
  systemd-login-Avoid-a-crash-on-container.patch
  vdagent-connection-Pass-err-to-g_credentials_get_uni.patch
  vdagentd-Automatically-release-agent_data.patch
  vdagentd-Avoid-calling-chmod.patch
  vdagentd-Better-check-for-vdagent_connection_get_pee.patch
  vdagentd-Limit-number-of-agents-per-session-to-1.patch
  vdagentd-Use-bool-for-agent_owns_clipboard-and-clien.patch
  vdagentd-do-not-allow-to-use-an-already-used-file-xf.patch
  vdagentd-init-static-uinput-before-fork.patch
  vdagentd-work-around-GLib-s-fork-issues.patch
* Mon Nov  2 2020 Bruce Rogers <brogers@suse.com>
- Fix multiple security issues as outlined in bsc#1173749
  bsc#1177780 bsc#1177781 bsc#1177782 bsc#1177783
  CVE-2020-25650 CVE-2020-25651 CVE-2020-25652 CVE-2020-25653
  systemd-login-Avoid-a-crash-on-container.patch
  vdagentd-Use-bool-for-agent_owns_clipboard-and-clien.patch
  vdagentd-Automatically-release-agent_data.patch
  vdagent-connection-Pass-err-to-g_credentials_get_uni.patch
  vdagentd-Better-check-for-vdagent_connection_get_pee.patch
  vdagentd-Avoid-calling-chmod.patch
  Avoids-unchecked-file-transfer-IDs-allocation-and-us.patch
  Avoids-uncontrolled-active_xfers-allocations.patch
  Avoids-unlimited-agent-connections.patch
  Avoids-user-session-hijacking.patch
  Better-check-for-sessions.patch
  vdagentd-Limit-number-of-agents-per-session-to-1.patch
  cleanup-active_xfers-when-the-client-disconnects.patch
  vdagentd-do-not-allow-to-use-an-already-used-file-xf.patch
  Add-a-test-for-session_info.patch
- Add a check section to run internal tests. Note that by default
  the added session_info test is not run, as it doesn't work in
  context of build service
* Wed Aug 19 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Fix invalid usage of %%{_libexecdir} to reference udev/rules.d.
* Thu Mar 26 2020 Bruce Rogers <brogers@suse.com>
- Fix issue of spice-vdagentd not shutting down (bsc#1166895)
  vdagentd-work-around-GLib-s-fork-issues.patch
  (This patch fixes a related issue)
  vdagentd-init-static-uinput-before-fork.patch
* Tue Mar 10 2020 Bruce Rogers <brogers@suse.com>
- Update to 0.20.0
  * Add gio-unix and gobject dependency >= 2.50
  * Bump gtk+ >= 3.22 (optional dependency)
  * Last release with gtk+ being optional
  * !4 - Race fixes between client and guest clipboard
  * !2 - Fix session lookup for new GNOME versions
  * !3 - Now using GMainLoop and GIO to handle I/O of messages
  * Several minor covscan fixes
- Discovered GLib dependency is now >= 2.58
- Patch dropped (contained in update):
  vdagentd-Fix-session-lookup-for-new-GNOME-versions.patch
* Thu Dec 19 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(libsystemd) instead of systemd-devel:
  Allow OBS to shortcut through the -mini flavors.
* Tue Dec 17 2019 Bruce Rogers <brogers@suse.com>
- Since the 0.19.0 update, this patch is no longer needed:
  spice-vdagent-var_run.patch
- For sometime now we've not had any rsyslog config files, so clean
  up where the spec file would remove the rsyslog.d dir and content
* Wed Dec 11 2019 Bruce Rogers <brogers@suse.com>
- Add upstream fix for spice-vdagent running on recent GNOME (eg.
  3.34) with systemd integration (boo#1157235)
  vdagentd-Fix-session-lookup-for-new-GNOME-versions.patch
* Fri May 17 2019 Bruce Rogers <brogers@suse.com>
- Update to 0.19.0
  * Add libdrm dependency
  * Fix file descriptor leak on failed connections
  * Handle new VD_AGENT_GRAPHICS_DEVICE_INFO message advertised by
    VD_AGENT_CAP_GRAPHICS_DEVICE_INFO capability
  * Session agent autostart changed to WindowManager ([rhbz#1623947])
    This fixes possible race with xdg-user-dirs
  * Fix of sending empty screen resolution messages ([rhbz#1641723])
  * Fix 'Dependency failed for Activation socket' with systemd ([rhbz#1545212])
  * Fix error messages about on selecting text on host ([rhbz#1594876])
    this was also fixed with Gtk backend
  * Update paths from /var/run → /run
  * Fix Session agent restart
  * Add test for file creation
  * Prefer GLib memory functions stdlib.h ones
  * Several code and logs improvements
  * Add GTK+ framework to handle x11 backend such as clipboard
  * Deprecate X11 backend in favor of GTK+ framework
  * Ask pkg-config to appropriate directory to install udev rules
  * Fix leak of udscs's file descriptor
  * Better quote directory path when calling xdg-open to save file transfer
  * Bump GLib to 2.34
  * Add systemd socket activation (rhbz#1340160)
  * Add support to detailed errors on file transfers
  * Add check for available free space in guest before starting a file transfer
  * Use better names for duplicated files on file transfer
  * Improve support on big endian guests (#5)
  * Use IdleHint to check if a session is locked over console-kit (rhbz#1412673)
  * Fixes double free on errors over udscs by improving memory ownership
  * Hide autostart file on Unity
  * Improve command line messages for vdagentd
  * Fix typo in --enable-static-uinput configure option
  * Code repository moved to gitlab.freedesktop.org
- Add keyring and tarball signature files
- obsoleted patches removed:
  8ba17481-quote-save-dir-before-passing-to-shell.patch
  vdagentd-do-endian-swapping.patch
* Tue Dec  5 2017 cbosdonnat@suse.com
- Fix potential shell command injection.
  8ba17481-quote-save-dir-before-passing-to-shell.patch
  CVE-2017-15108 (bsc#1070724)
* Thu Jul 27 2017 msuchanek@suse.com
- Fix warning in vdagentd-do-endian-swapping.patch
* Mon Feb 20 2017 msuchanek@suse.com
- Add endian swapping to run on BE guests (boo#1012215).
  vdagentd-do-endian-swapping.patch
* Fri Nov 25 2016 zaitor@opensuse.org
- Add pkgconfig(glib-2.0) BuildRequires: Explicit dependency.
- Handle spice-vdagentd.target in pre/post/preun/postun.
- Handle spice-vdagentd.conf in post via tmpfiles_create macro.
* Fri Nov 25 2016 seife+obs@b1-systems.com
- Update to 0.17.0
  * Denies file-transfer in locked sessions
  * Denies file-transfer in login screen
  * Bump glib version to 2.28
  * Set exit code to 1 instead of 0 when virtio device cannot be
    opened
  * Fix double-free on uinput->screen_info (rhbz#1262635)
  * Code improvement over unix domain client server support (udcs)
  * Fix build compatiblity with different libsystemd versions
    (fdo#94209)
- obsoleted patches removed:
  8c465007-vdagentd-fixes-small-leak.patch
  f97751fa-revert-uinput-fix-small-leak-of-screen_info.patch
- package: add explicit buildrequires for pkgconfig(dbus-1)
* Tue Sep  6 2016 cbosdonnat@suse.com
- Fix crash when changing guest display's resolution (bsc#997236)
  8c465007-vdagentd-fixes-small-leak.patch
  f97751fa-revert-uinput-fix-small-leak-of-screen_info.patch
* Thu Jun  2 2016 cbosdonnat@suse.com
- fate#320079
* Tue Jul 21 2015 mpluskal@suse.com
- Update tp 0.16.0
  * Xspice support
  * Release clipboard on client disconnect if owned by client
    (rhbz#1003977)
  * Turn some error messages into debugging messages (rhbz#918310)
  * Not having the virtio channel is not an error; instead silently
    do nothing
- Cleanup spec file with spec-cleaner
- Actually apply spice-vdagent-var_run.patch
* Wed Jul  9 2014 fcrozat@suse.com
- Add supplements on virtio_console to automatically install
  spice-vdagent when X11 server is installed on KVM with Spice
  enabled.
* Tue Jul  1 2014 fcrozat@suse.com
- Enable systemd service at initial install, it is needed for
  udev rules to properly start the agent.
* Tue May 27 2014 ohering@suse.de
- fix /var/run handling
  spice-vdagent-var_run.patch
* Mon Feb  3 2014 seife+obs@b1-systems.com
- run spec-cleaner
- remove autoreconf call
* Sun Feb  2 2014 seife+obs@b1-systems.com
- import the spec file from fedora core 21, adapt for openSUSE
- version 0.15.0
